@@ -24,7 +24,7 @@ try:
     import matplotlib
     from scipy.optimize import curve_fit
     import math as ma
-    print "Imports all good"
+    #print "Imports all good"
 except:
     print "Numerical libraries not present in your systems"
 
